/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Chimera code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Aaron Schulman <aschulm@umd.edu>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#import "RolloverImageButton.h"

@implementation RolloverImageButton

-(id)initWithFrameAndImages:(NSRect)frame:(NSImage*)pUpImage:(NSImage*)pDownImage:(NSImage*)pHoverImage
{
  if ((self = [super initWithFrame:frame])) 
  {
    mUpImage = pUpImage;
    mDownImage = pDownImage;
    mHoverImage = pHoverImage;
    mTrackingTag = -1;
    
    // set the default images for the button to be the upImage and downImage
    [super setImage:pUpImage];
    [super setAlternateImage:pDownImage];
  }
  return self;
}

-(void)removeFromSuperview
{
  [[self superview] removeTrackingRect:mTrackingTag];
  [super removeFromSuperview];
}

-(void)setFrame:(NSRect)pFrame
{
  [super setFrame:pFrame];
  if (mTrackingTag != -1)
    [[self superview] removeTrackingRect:mTrackingTag];
    
  // setting the close button state based on where the mouse pointer is
  NSPoint mousePointInWindow = [[self window] convertScreenToBase:[NSEvent mouseLocation]];
  NSPoint mousePointInView = [[self superview] convertPoint:mousePointInWindow fromView:nil];
  BOOL mouseInside = NSMouseInRect(mousePointInView,pFrame,NO);
  mTrackingTag = [[self superview] addTrackingRect:pFrame owner:self userData:nil assumeInside:mouseInside];
  [self updateImage:mouseInside];
}

-(void)mouseEntered:(NSEvent*)theEvent
{
  if ([theEvent trackingNumber] == mTrackingTag) 
  {
    [self updateImage:YES];
  }
}

-(void)mouseExited:(NSEvent*)theEvent
{
  if ([theEvent trackingNumber] == mTrackingTag)
  {
    mMouseInside = false;
    [self updateImage:NO];
  }
}

-(void)setUpImage:(NSImage*)pImage
{
  mUpImage = pImage;
}

-(void)setDownImage:(NSImage*)pImage
{
  mDownImage = pImage;
}

-(void)setHoverImage:(NSImage*)pImage
{
  mHoverImage = pImage;
}

-(void)updateImage:(BOOL)pIsInside
{
  if (pIsInside)
    [super setImage:mHoverImage];
  else
    [super setImage:mUpImage];
  [self setNeedsDisplay:YES];
}
@end
